@@ -208,7 +208,6 @@ struct AbletonLiveHostSpecific
 */
 class JuceVSTWrapper final : public AudioProcessorListener,
                              public AudioPlayHead,
-                             private Timer,
                              private AudioProcessorParameter::Listener
 {
 private:
@@ -324,7 +323,7 @@ public:
             MessageManagerLock mmLock;
            #endif
 
-            stopTimer();
+            timedCallback.stopTimer();
             deleteEditor (false);
 
             hasShutdown = true;
@@ -375,9 +374,7 @@ public:
            #endif
         }
 
-       #if JUCE_DEBUG && ! (JucePlugin_ProducesMidiOutput || JucePlugin_IsMidiEffect)
-        const int numMidiEventsComingIn = midiEvents.getNumEvents();
-       #endif
+        const auto numMidiEventsComingIn = midiEvents.getNumEvents();
 
         {
             const int numIn  = processor->getTotalNumInputChannels();
@@ -462,38 +459,41 @@ public:
 
         if (! midiEvents.isEmpty())
         {
-           #if JucePlugin_ProducesMidiOutput || JucePlugin_IsMidiEffect
-            auto numEvents = midiEvents.getNumEvents();
-
-            outgoingEvents.ensureSize (numEvents);
-            outgoingEvents.clear();
-
-            for (const auto metadata : midiEvents)
+            if (supportsMidiOut)
             {
-                jassert (metadata.samplePosition >= 0 && metadata.samplePosition < numSamples);
+                auto numEvents = midiEvents.getNumEvents();
 
-                outgoingEvents.addEvent (metadata.data, metadata.numBytes, metadata.samplePosition);
+                outgoingEvents.ensureSize (numEvents);
+                outgoingEvents.clear();
+
+                for (const auto metadata : midiEvents)
+                {
+                    jassert (metadata.samplePosition >= 0 && metadata.samplePosition < numSamples);
+
+                    outgoingEvents.addEvent (metadata.data, metadata.numBytes, metadata.samplePosition);
+                }
+
+                // Send VST events to the host.
+                NullCheckedInvocation::invoke (hostCallback, &vstEffect, Vst2::audioMasterProcessEvents, 0, 0, outgoingEvents.events, 0.0f);
             }
+            else
+            {
+                /*  This assertion is caused when you've added some events to the
+                    midiMessages array in your processBlock() method, which usually means
+                    that you're trying to send them somewhere. But in this case they're
+                    getting thrown away.
 
-            // Send VST events to the host.
-            NullCheckedInvocation::invoke (hostCallback, &vstEffect, Vst2::audioMasterProcessEvents, 0, 0, outgoingEvents.events, 0.0f);
-           #elif JUCE_DEBUG
-            /*  This assertion is caused when you've added some events to the
-                midiMessages array in your processBlock() method, which usually means
-                that you're trying to send them somewhere. But in this case they're
-                getting thrown away.
+                    If your plugin does want to send midi messages, you'll need to set
+                    the JucePlugin_ProducesMidiOutput macro to 1 in your
+                    JucePluginCharacteristics.h file.
 
-                If your plugin does want to send midi messages, you'll need to set
-                the JucePlugin_ProducesMidiOutput macro to 1 in your
-                JucePluginCharacteristics.h file.
-
-                If you don't want to produce any midi output, then you should clear the
-                midiMessages array at the end of your processBlock() method, to
-                indicate that you don't want any of the events to be passed through
-                to the output.
-            */
-            jassert (midiEvents.getNumEvents() <= numMidiEventsComingIn);
-           #endif
+                    If you don't want to produce any midi output, then you should clear the
+                    midiMessages array at the end of your processBlock() method, to
+                    indicate that you don't want any of the events to be passed through
+                    to the output.
+                */
+                jassertquiet (midiEvents.getNumEvents() <= numMidiEventsComingIn);
+            }
 
             midiEvents.clear();
         }
@@ -553,7 +553,7 @@ public:
                 host that we want midi. In the SDK this method is marked as deprecated, but
                 some hosts rely on this behaviour.
             */
-            if (vstEffect.flags & Vst2::effFlagsIsSynth || JucePlugin_WantsMidiInput || JucePlugin_IsMidiEffect)
+            if (vstEffect.flags & Vst2::effFlagsIsSynth || supportsMidiIn)
                 NullCheckedInvocation::invoke (hostCallback, &vstEffect, Vst2::audioMasterWantMidi, 0, 1, nullptr, 0.0f);
 
             if (detail::PluginUtilities::getHostType().isAbletonLive()
@@ -570,9 +570,8 @@ public:
                 hostCallback (&vstEffect, Vst2::audioMasterVendorSpecific, 0, 0, &hostCmd, 0.0f);
             }
 
-           #if JucePlugin_ProducesMidiOutput || JucePlugin_IsMidiEffect
-            outgoingEvents.ensureSize (512);
-           #endif
+            if (supportsMidiOut)
+                outgoingEvents.ensureSize (512);
         }
     }
 
@@ -779,27 +778,6 @@ public:
     }
 
     //==============================================================================
-    void timerCallback() override
-    {
-        if (shouldDeleteEditor)
-        {
-            shouldDeleteEditor = false;
-            deleteEditor (true);
-        }
-
-        {
-            ScopedLock lock (stateInformationLock);
-
-            if (chunkMemoryTime > 0
-                 && chunkMemoryTime < juce::Time::getApproximateMillisecondCounter() - 2000
-                 && ! recursionCheck)
-            {
-                chunkMemory.reset();
-                chunkMemoryTime = 0;
-            }
-        }
-    }
-
     void setHasEditorFlag (bool shouldSetHasEditor)
     {
         auto hasEditor = (vstEffect.flags & Vst2::effFlagsHasEditor) != 0;
@@ -1472,7 +1450,7 @@ private:
     pointer_sized_int handleClose (VstOpCodeArguments)
     {
         // Note: most hosts call this on the UI thread, but wavelab doesn't, so be careful in here.
-        stopTimer();
+        timedCallback.stopTimer();
 
         if (MessageManager::getInstance()->isThisTheMessageThread())
             deleteEditor (false);
@@ -1594,7 +1572,7 @@ private:
        #endif
         jassert (! recursionCheck);
 
-        startTimerHz (4); // performs misc housekeeping chores
+        timedCallback.startTimerHz (4); // performs misc housekeeping chores
 
         deleteEditor (true);
         createEditorComp();
@@ -1680,12 +1658,13 @@ private:
 
     pointer_sized_int handlePreAudioProcessingEvents ([[maybe_unused]] VstOpCodeArguments args)
     {
-       #if JucePlugin_WantsMidiInput || JucePlugin_IsMidiEffect
-        VSTMidiEventList::addEventsToMidiBuffer ((Vst2::VstEvents*) args.ptr, midiEvents);
-        return 1;
-       #else
+        if (supportsMidiIn)
+        {
+            VSTMidiEventList::addEventsToMidiBuffer ((Vst2::VstEvents*) args.ptr, midiEvents);
+            return 1;
+        }
+
         return 0;
-       #endif
     }
 
     pointer_sized_int handleIsParameterAutomatable (VstOpCodeArguments args)
@@ -1841,22 +1820,14 @@ private:
          || matches ("receiveVstMidiEvent")
          || matches ("receiveVstMidiEvents"))
         {
-           #if JucePlugin_WantsMidiInput || JucePlugin_IsMidiEffect
-            return 1;
-           #else
-            return -1;
-           #endif
+            return supportsMidiIn ? 1 : -1;
         }
 
         if (matches ("sendVstEvents")
          || matches ("sendVstMidiEvent")
          || matches ("sendVstMidiEvents"))
         {
-           #if JucePlugin_ProducesMidiOutput || JucePlugin_IsMidiEffect
-            return 1;
-           #else
-            return -1;
-           #endif
+            return supportsMidiOut ? 1 : -1;
         }
 
         if (matches ("receiveVstTimeInfo")
@@ -2023,28 +1994,30 @@ private:
     //==============================================================================
     pointer_sized_int handleGetNumMidiInputChannels()
     {
-       #if JucePlugin_WantsMidiInput || JucePlugin_IsMidiEffect
-        #ifdef JucePlugin_VSTNumMidiInputs
-         return JucePlugin_VSTNumMidiInputs;
-        #else
-         return 16;
-        #endif
-       #else
+        if (supportsMidiIn)
+        {
+           #ifdef JucePlugin_VSTNumMidiInputs
+            return JucePlugin_VSTNumMidiInputs;
+           #else
+            return 16;
+           #endif
+        }
+
         return 0;
-       #endif
     }
 
     pointer_sized_int handleGetNumMidiOutputChannels()
     {
-       #if JucePlugin_ProducesMidiOutput || JucePlugin_IsMidiEffect
-        #ifdef JucePlugin_VSTNumMidiOutputs
-         return JucePlugin_VSTNumMidiOutputs;
-        #else
-         return 16;
-        #endif
-       #else
+        if (supportsMidiOut)
+        {
+           #ifdef JucePlugin_VSTNumMidiOutputs
+            return JucePlugin_VSTNumMidiOutputs;
+           #else
+            return 16;
+           #endif
+        }
+
         return 0;
-       #endif
     }
 
     pointer_sized_int handleEditIdle()
@@ -2064,6 +2037,27 @@ private:
     SharedResourcePointer<detail::MessageThread> messageThread;
    #endif
 
+    TimedCallback timedCallback { [this]
+    {
+        if (shouldDeleteEditor)
+        {
+            shouldDeleteEditor = false;
+            deleteEditor (true);
+        }
+
+        {
+            ScopedLock lock (stateInformationLock);
+
+            if (chunkMemoryTime > 0
+                && chunkMemoryTime < juce::Time::getApproximateMillisecondCounter() - 2000
+                && ! recursionCheck)
+            {
+                chunkMemory.reset();
+                chunkMemoryTime = 0;
+            }
+        }
+    } };
+
     Vst2::audioMasterCallback hostCallback;
     std::unique_ptr<AudioProcessor> processor;
     double sampleRate = 44100.0;
@@ -2083,6 +2077,8 @@ private:
 
     bool isProcessing = false, isBypassed = false, hasShutdown = false;
     bool firstProcessCallback = true, shouldDeleteEditor = false;
+    const bool supportsMidiIn  = processor->isMidiEffect() || processor->acceptsMidi();
+    const bool supportsMidiOut = processor->isMidiEffect() || processor->producesMidi();
 
     VstTempBuffers<float> floatTempBuffers;
     VstTempBuffers<double> doubleTempBuffers;
