@@ -297,33 +297,10 @@ bool File::moveToTrash() const
 
     JUCE_AUTORELEASEPOOL
     {
-        if (@available (macOS 10.8, iOS 11.0, *))
-        {
-            NSError* error = nil;
-            return [[NSFileManager defaultManager] trashItemAtURL: createNSURLFromFile (*this)
-                                                 resultingItemURL: nil
-                                                            error: &error];
-        }
-
-       #if JUCE_IOS
-        return deleteFile();
-       #else
-        [[NSWorkspace sharedWorkspace] recycleURLs: [NSArray arrayWithObject: createNSURLFromFile (*this)]
-                                 completionHandler: nil];
-
-        // recycleURLs is async, so we need to block until it has finished. We can't use a
-        // run-loop here because it'd dispatch unexpected messages, so have to do this very
-        // nasty bodge. But this is only needed for support of pre-10.8 versions.
-        for (int retries = 100; --retries >= 0;)
-        {
-            if (! exists())
-                return true;
-
-            Thread::sleep (5);
-        }
-
-        return false;
-       #endif
+        NSError* error = nil;
+        return [[NSFileManager defaultManager] trashItemAtURL: createNSURLFromFile (*this)
+                                             resultingItemURL: nil
+                                                        error: &error];
     }
 }
 
@@ -418,18 +395,11 @@ bool JUCE_CALLTYPE Process::openDocument (const String& fileName, [[maybe_unused
                                                                                        : [NSURL URLWithString: fileNameAsNS];
 
       #if JUCE_IOS
-        if (@available (iOS 10.0, *))
-        {
-            [[UIApplication sharedApplication] openURL: filenameAsURL
-                                               options: @{}
-                                     completionHandler: nil];
+        [[UIApplication sharedApplication] openURL: filenameAsURL
+                                           options: @{}
+                                 completionHandler: nil];
 
-            return true;
-        }
-
-        JUCE_BEGIN_IGNORE_WARNINGS_GCC_LIKE ("-Wdeprecated-declarations")
-        return [[UIApplication sharedApplication] openURL: filenameAsURL];
-        JUCE_END_IGNORE_WARNINGS_GCC_LIKE
+        return true;
       #else
         NSWorkspace* workspace = [NSWorkspace sharedWorkspace];
 
@@ -448,7 +418,6 @@ bool JUCE_CALLTYPE Process::openDocument (const String& fileName, [[maybe_unused
             for (int i = 0; i < params.size(); ++i)
                 [paramArray addObject: juceStringToNS (params[i])];
 
-           #if defined (MAC_OS_X_VERSION_10_15) && MAC_OS_X_VERSION_MAX_ALLOWED >= MAC_OS_X_VERSION_10_15
             if (@available (macOS 10.15, *))
             {
                 auto config = [NSWorkspaceOpenConfiguration configuration];
@@ -461,7 +430,6 @@ bool JUCE_CALLTYPE Process::openDocument (const String& fileName, [[maybe_unused
 
                 return true;
             }
-           #endif
 
             JUCE_BEGIN_IGNORE_WARNINGS_GCC_LIKE ("-Wdeprecated-declarations")
 
@@ -534,9 +502,8 @@ void File::addToDock() const
 
 File File::getContainerForSecurityApplicationGroupIdentifier (const String& appGroup)
 {
-    if (@available (macOS 10.8, *))
-        if (auto* url = [[NSFileManager defaultManager] containerURLForSecurityApplicationGroupIdentifier: juceStringToNS (appGroup)])
-            return File (nsStringToJuce ([url path]));
+    if (auto* url = [[NSFileManager defaultManager] containerURLForSecurityApplicationGroupIdentifier: juceStringToNS (appGroup)])
+        return File (nsStringToJuce ([url path]));
 
     return File();
 }
