@@ -40,9 +40,9 @@ struct Direct2DHwndContext::HwndPimpl : public Direct2DGraphicsContext::Pimpl
 private:
     struct SwapChainThread : private AsyncUpdater
     {
-        explicit SwapChainThread (Direct2DHwndContext::HwndPimpl& ownerIn)
+        SwapChainThread (Direct2DHwndContext::HwndPimpl& ownerIn, HANDLE swapHandle)
             : owner (ownerIn),
-              swapChainEventHandle (ownerIn.swap.swapChainEvent->getHandle())
+              swapChainEventHandle (swapHandle)
         {
         }
 
@@ -53,6 +53,8 @@ private:
             thread.join();
         }
 
+        JUCE_DECLARE_NON_COPYABLE_WITH_LEAK_DETECTOR (SwapChainThread)
+
     private:
         Direct2DHwndContext::HwndPimpl& owner;
         HANDLE swapChainEventHandle = nullptr;
@@ -141,16 +143,14 @@ private:
         {
             if (auto hr = swap.create (hwnd, getClientRect(), adapter); FAILED (hr))
                 return false;
-
-            if (auto hr = swap.createBuffer (getDeviceContext()); FAILED (hr))
-                return false;
         }
 
-        if (! swapChainThread && swap.swapChainEvent.has_value())
-            swapChainThread = std::make_unique<SwapChainThread> (*this);
+        if (swapChainThread == nullptr)
+            if (auto* e = swap.getEvent())
+                swapChainThread = std::make_unique<SwapChainThread> (*this, e->getHandle());
 
         if (! compositionTree.has_value())
-            compositionTree = CompositionTree::create (adapter->dxgiDevice, hwnd, swap.chain);
+            compositionTree = CompositionTree::create (adapter->dxgiDevice, hwnd, swap.getChain());
 
         if (! compositionTree.has_value())
             return false;
@@ -163,7 +163,7 @@ private:
         compositionTree.reset();
         swapChainThread = nullptr;
         deviceContext = nullptr;
-        swap.release();
+        swap = {};
 
         Pimpl::teardown();
     }
@@ -179,13 +179,8 @@ private:
         if (auto now = Time::getHighResolutionTicks(); Time::highResolutionTicksToSeconds (now - lastFinishFrameTicks) < 0.001)
             return false;
 
-        // Paint if:
-        //      resources are allocated
-        //      deferredRepaints has areas to be painted
-        //      the swap chain thread is ready
         bool ready = Pimpl::checkPaintReady();
         ready &= swap.canPaint();
-        ready &= swap.buffer != nullptr;
         ready &= compositionTree.has_value();
 
         return ready;
@@ -231,7 +226,7 @@ public:
 
     ComSmartPtr<ID2D1Image> getDeviceContextTarget() const override
     {
-        return swap.buffer;
+        return swap.getBuffer();
     }
 
     void setSize (Rectangle<int> size)
@@ -250,13 +245,10 @@ public:
         // Resize/scale the swap chain
         prepare();
 
-        if (auto dc = getDeviceContext())
-        {
-            auto hr = swap.resize (size, dc);
-            jassert (SUCCEEDED (hr));
-            if (FAILED (hr))
-                teardown();
-        }
+        auto hr = swap.resize (size);
+        jassert (SUCCEEDED (hr));
+        if (FAILED (hr))
+            teardown();
     }
 
     void addDeferredRepaint (Rectangle<int> deferredRepaint)
@@ -298,7 +290,7 @@ public:
     {
         JUCE_D2DMETRICS_SCOPED_ELAPSED_TIME (owner.metrics, present1Duration);
 
-        if (swap.buffer == nullptr || dirtyRegionsInBackBuffer.isEmpty() || ! swapEventReceived)
+        if (swap.getBuffer() == nullptr || dirtyRegionsInBackBuffer.isEmpty() || ! swapEventReceived)
             return;
 
         auto const swapChainSize = swap.getSize();
@@ -321,7 +313,7 @@ public:
         }
 
         // Present the freshly painted buffer
-        const auto hr = swap.chain->Present1 (swap.presentSyncInterval, swap.presentFlags, &presentParameters);
+        const auto hr = swap.getChain()->Present1 (swap.presentSyncInterval, swap.presentFlags, &presentParameters);
         jassertquiet (SUCCEEDED (hr));
 
         if (FAILED (hr))
@@ -344,36 +336,39 @@ public:
         // This won't capture child windows. Perhaps a better approach would be to use
         // IGraphicsCaptureItemInterop, although this is only supported on Windows 10 v1903+
 
-        const auto context = getDeviceContext();
+        if (deviceContext == nullptr)
+            return {};
 
-        if (context == nullptr || swap.buffer == nullptr)
+        const auto buffer = swap.getBuffer();
+
+        if (buffer == nullptr)
             return {};
 
         // Create the bitmap to receive the snapshot
         D2D1_BITMAP_PROPERTIES1 bitmapProperties{};
         bitmapProperties.bitmapOptions = D2D1_BITMAP_OPTIONS_TARGET;
-        bitmapProperties.pixelFormat = swap.buffer->GetPixelFormat();
+        bitmapProperties.pixelFormat = buffer->GetPixelFormat();
 
         const auto swapRect = swap.getSize();
         const auto size = D2D1::SizeU ((UINT32) swapRect.getWidth(), (UINT32) swapRect.getHeight());
 
         ComSmartPtr<ID2D1Bitmap1> snapshot;
 
-        if (const auto hr = context->CreateBitmap (size, nullptr, 0, bitmapProperties, snapshot.resetAndGetPointerAddress()); FAILED (hr))
+        if (const auto hr = deviceContext->CreateBitmap (size, nullptr, 0, bitmapProperties, snapshot.resetAndGetPointerAddress()); FAILED (hr))
             return {};
 
-        swap.chain->Present (0, DXGI_PRESENT_DO_NOT_WAIT);
+        swap.getChain()->Present (0, DXGI_PRESENT_DO_NOT_WAIT);
 
         // Copy the swap chain buffer to the bitmap snapshot
         D2D_POINT_2U p { 0, 0 };
         const auto sourceRect = D2DUtilities::toRECT_U (swapRect);
 
-        if (const auto hr = snapshot->CopyFromBitmap (&p, swap.buffer, &sourceRect); FAILED (hr))
+        if (const auto hr = snapshot->CopyFromBitmap (&p, buffer, &sourceRect); FAILED (hr))
             return {};
 
-        const Image result { new Direct2DPixelData { context, snapshot } };
+        const Image result { new Direct2DPixelData { deviceContext, snapshot } };
 
-        swap.chain->Present (0, DXGI_PRESENT_DO_NOT_WAIT);
+        swap.getChain()->Present (0, DXGI_PRESENT_DO_NOT_WAIT);
 
         return result;
     }
