@@ -337,7 +337,6 @@ struct MenuWindow final : public Component
                 MenuWindow* parentWindow,
                 Options opts,
                 bool alignToRectangle,
-                bool shouldDismissOnMouseUp,
                 ApplicationCommandManager** manager,
                 float parentScaleFactor = 1.0f)
         : Component ("menu"),
@@ -345,7 +344,6 @@ struct MenuWindow final : public Component
           options (opts.withParentComponent (findNonNullLookAndFeel (menu, parentWindow).getParentComponentForMenuOptions (opts))),
           managerOfChosenCommand (manager),
           componentAttachedTo (options.getTargetComponent()),
-          dismissOnMouseUp (shouldDismissOnMouseUp),
           windowCreationTime (Time::getMillisecondCounter()),
           lastFocusedTime (windowCreationTime),
           timeEnteredCurrentChildComp (windowCreationTime),
@@ -703,21 +701,35 @@ struct MenuWindow final : public Component
     }
 
     //==============================================================================
-    void mouseMove  (const MouseEvent& e) override    { handleMouseEvent (e); }
     void mouseDown  (const MouseEvent& e) override    { handleMouseEvent (e); }
-    void mouseDrag  (const MouseEvent& e) override    { handleMouseEvent (e); }
-    void mouseUp    (const MouseEvent& e) override    { handleMouseEvent (e); }
+
+    void mouseUp (const MouseEvent& e) override
+    {
+        SafePointer self { this };
+
+        handleMouseEvent (e);
+
+        // Check whether this menu was deleted as a result of the mouse being released.
+        if (self == nullptr)
+            return;
+
+        // If the mouse was down when the menu was created, releasing the mouse should
+        // not trigger the item under the mouse, because we might still be handling the click
+        // that caused the menu to show in the first place. Once the mouse has been released once,
+        // then the user must have clicked the mouse again, so they are attempting to trigger or
+        // dismiss the menu.
+        mouseUpCanTrigger |= true;
+    }
+
+    // Any move/drag after the menu is created will allow the mouse to trigger a highlighted item
+    void mouseDrag  (const MouseEvent& e) override    { mouseUpCanTrigger |= true; handleMouseEvent (e); }
+    void mouseMove  (const MouseEvent& e) override    { mouseUpCanTrigger |= true; handleMouseEvent (e); }
 
     void mouseWheelMove (const MouseEvent&, const MouseWheelDetails& wheel) override
     {
         alterChildYPos (roundToInt (-10.0f * wheel.deltaY * PopupMenuSettings::scrollZone));
     }
 
-    void handleMouseEvent (const MouseEvent& e)
-    {
-        getMouseState (e.source).handleMouseEvent (e);
-    }
-
     bool windowIsStillValid()
     {
         if (! isVisible())
@@ -1211,7 +1223,7 @@ struct MenuWindow final : public Component
                                                             options.forSubmenu()
                                                                    .withTargetScreenArea (childComp->getScreenBounds())
                                                                    .withMinimumWidth (0),
-                                                            false, dismissOnMouseUp, managerOfChosenCommand, scaleFactor));
+                                                            false, managerOfChosenCommand, scaleFactor));
 
         activeSubMenu->setVisible (true); // (must be called before enterModalState on Windows to avoid DropShadower confusion)
         activeSubMenu->enterModalState (false);
@@ -1222,9 +1234,7 @@ struct MenuWindow final : public Component
     void triggerCurrentlyHighlightedItem()
     {
         if (currentChild != nullptr && canBeTriggered (currentChild->item))
-        {
             dismissMenu (&currentChild->item);
-        }
     }
 
     enum class MenuSelectionDirection
@@ -1315,6 +1325,9 @@ struct MenuWindow final : public Component
         return getLookAndFeel();
     }
 
+    bool mouseHasBeenOver() const { return mouseWasOver; }
+    bool allowMouseUpToTriggerItem() const { return mouseUpCanTrigger; }
+
     //==============================================================================
     MenuWindow* parent;
     const Options options;
@@ -1322,8 +1335,8 @@ struct MenuWindow final : public Component
     ApplicationCommandManager** managerOfChosenCommand;
     WeakReference<Component> componentAttachedTo;
     Rectangle<int> windowPos;
-    bool hasBeenOver = false, needsToScroll = false;
-    bool dismissOnMouseUp, hideOnExit = false, disableMouseMoves = false, hasAnyJuceCompHadFocus = false;
+    bool needsToScroll = false;
+    bool hideOnExit = false, disableMouseMoves = false, hasAnyJuceCompHadFocus = false;
     int numColumns = 0, contentHeight = 0, childYOffset = 0;
     Component::SafePointer<ItemComponent> currentChild;
     std::unique_ptr<MenuWindow> activeSubMenu;
@@ -1333,6 +1346,16 @@ struct MenuWindow final : public Component
     float scaleFactor;
     bool exitingModalState = false;
 
+private:
+    void handleMouseEvent (const MouseEvent& e)
+    {
+        mouseWasOver |= reallyContains (getLocalPoint (nullptr, e.getScreenPosition()), true);
+        getMouseState (e.source).handleMouseEvent (e);
+    }
+
+    bool mouseWasOver = false;
+    bool mouseUpCanTrigger = ! ModifierKeys::currentModifiers.isAnyMouseButtonDown();
+
     JUCE_DECLARE_NON_COPYABLE_WITH_LEAK_DETECTOR (MenuWindow)
 };
 
@@ -1400,7 +1423,7 @@ private:
         const bool overScrollArea = scrollIfNecessary (localMousePos, timeNow);
         const bool isOverAny = window.isOverAnyMenu();
 
-        if (window.hideOnExit && window.hasBeenOver && ! isOverAny)
+        if (window.hideOnExit && window.mouseHasBeenOver() && ! isOverAny)
             window.hide (nullptr, true);
         else
             checkButtonState (localMousePos, timeNow, isDown, overScrollArea, isOverAny);
@@ -1409,7 +1432,7 @@ private:
     void checkButtonState (Point<int> localMousePos, const uint32 timeNow,
                            const bool wasDown, const bool overScrollArea, const bool isOverAny)
     {
-        isDown = window.hasBeenOver
+        isDown = window.mouseHasBeenOver()
                     && (ModifierKeys::currentModifiers.isAnyMouseButtonDown()
                          || ComponentPeer::getCurrentModifiersRealtime().isAnyMouseButtonDown());
 
@@ -1426,9 +1449,9 @@ private:
         }
         else if (wasDown && timeNow > window.windowCreationTime + 250 && ! isDown && ! overScrollArea)
         {
-            if (reallyContained)
+            if (reallyContained && window.allowMouseUpToTriggerItem())
                 window.triggerCurrentlyHighlightedItem();
-            else if ((window.hasBeenOver || ! window.dismissOnMouseUp) && ! isOverAny)
+            else if ((window.mouseHasBeenOver() || ! window.allowMouseUpToTriggerItem()) && ! isOverAny)
                 window.dismissMenu (nullptr);
 
             // Note: This object may have been deleted by the previous call.
@@ -1445,9 +1468,6 @@ private:
         {
             const auto isMouseOver = window.reallyContains (localMousePos, true);
 
-            if (isMouseOver)
-                window.hasBeenOver = true;
-
             if (lastMousePos.getDistanceFrom (globalMousePos) > 2)
             {
                 lastMouseMoveTime = timeNow;
@@ -1484,7 +1504,7 @@ private:
 
                     if (! isMouseOver)
                     {
-                        if (! window.hasBeenOver)
+                        if (! window.mouseHasBeenOver())
                             return;
 
                         itemUnderMouse = nullptr;
@@ -2073,7 +2093,6 @@ Component* PopupMenu::createWindow (const Options& options,
     return items.isEmpty() ? nullptr
                            : new HelperClasses::MenuWindow (*this, nullptr, options,
                                                             ! options.getTargetScreenArea().isEmpty(),
-                                                            ModifierKeys::currentModifiers.isAnyMouseButtonDown(),
                                                             managerOfChosenCommand);
 }
 
