@@ -307,32 +307,6 @@ struct CADisplayLinkDeleter
     std::unique_ptr<CADisplayLink, CADisplayLinkDeleter> displayLink;
 }
 
-- (JuceUIView*) initWithOwner: (UIViewComponentPeer*) owner withFrame: (CGRect) frame;
-- (void) dealloc;
-
-+ (Class) layerClass;
-
-- (void) displayLinkCallback: (CADisplayLink*) dl;
-
-- (void) drawRect: (CGRect) r;
-
-- (void) touchesBegan:     (NSSet*) touches  withEvent: (UIEvent*) event;
-- (void) touchesMoved:     (NSSet*) touches  withEvent: (UIEvent*) event;
-- (void) touchesEnded:     (NSSet*) touches  withEvent: (UIEvent*) event;
-- (void) touchesCancelled: (NSSet*) touches  withEvent: (UIEvent*) event;
-
-- (void) onHover: (UIHoverGestureRecognizer*) gesture API_AVAILABLE (ios (13.0));
-- (void) onScroll: (UIPanGestureRecognizer*) gesture;
-
-- (BOOL) becomeFirstResponder;
-- (BOOL) resignFirstResponder;
-- (BOOL) canBecomeFirstResponder;
-
-- (void) traitCollectionDidChange: (UITraitCollection*) previousTraitCollection;
-
-- (BOOL) isAccessibilityElement;
-- (CGRect) accessibilityFrame;
-- (NSArray*) accessibilityElements;
 @end
 
 //==============================================================================
@@ -420,7 +394,7 @@ public:
     void setIcon (const Image& newIcon) override;
     StringArray getAvailableRenderingEngines() override       { return StringArray ("CoreGraphics Renderer"); }
 
-    void displayLinkCallback();
+    void displayLinkCallback (double timestampSec);
 
     void drawRect (CGRect);
     void drawRectWithContext (CGContextRef, CGRect);
@@ -768,7 +742,7 @@ MultiTouchMapper<UITouch*> UIViewComponentPeer::currentTouches;
 - (void) displayLinkCallback: (CADisplayLink*) dl
 {
     if (owner != nullptr)
-        owner->displayLinkCallback();
+        owner->displayLinkCallback (dl.targetTimestamp);
 }
 
 #if JUCE_COREGRAPHICS_RENDER_WITH_MULTIPLE_PAINT_CALLS
@@ -846,7 +820,7 @@ MultiTouchMapper<UITouch*> UIViewComponentPeer::currentTouches;
     [self touchesEnded: touches withEvent: event];
 }
 
-- (void) onHover: (UIHoverGestureRecognizer*) gesture
+- (void) onHover: (UIHoverGestureRecognizer*) gesture API_AVAILABLE (ios (13))
 {
     if (owner != nullptr)
         owner->onHover (gesture);
@@ -891,7 +865,7 @@ static std::optional<int> getKeyCodeForSpecialCharacterString (StringRef charact
                              { nsStringToJuce (UIKeyInputF12),           KeyPress::F12Key } });
         }
 
-       #if defined (__IPHONE_15_0) && __IPHONE_OS_VERSION_MAX_ALLOWED >= __IPHONE_15_0
+       #if JUCE_IOS_API_VERSION_CAN_BE_BUILT (15, 0)
         if (@available (iOS 15.0, *))
         {
             result.insert ({ { nsStringToJuce (UIKeyInputDelete),        KeyPress::deleteKey } });
@@ -1045,10 +1019,8 @@ static bool doKeysUp (UIViewComponentPeer* owner, NSSet<UIPress*>* presses, UIPr
     return owner != nullptr && owner->canBecomeKeyWindow();
 }
 
-- (void) traitCollectionDidChange: (UITraitCollection*) previousTraitCollection
+static void postTraitChangeNotification (UITraitCollection* previousTraitCollection)
 {
-    [super traitCollectionDidChange: previousTraitCollection];
-
     const auto wasDarkModeActive = ([previousTraitCollection userInterfaceStyle] == UIUserInterfaceStyleDark);
 
     if (wasDarkModeActive != Desktop::getInstance().isDarkModeActive())
@@ -1056,6 +1028,18 @@ static bool doKeysUp (UIViewComponentPeer* owner, NSSet<UIPress*>* presses, UIPr
                                                             object: nil];
 }
 
+#if ! JUCE_IOS_API_VERSION_MIN_REQUIRED_AT_LEAST (17, 0)
+- (void) traitCollectionDidChange: (UITraitCollection*) previousTraitCollection
+{
+    [super traitCollectionDidChange: previousTraitCollection];
+
+    if (@available (ios 17, *))
+        {} // do nothing
+    else
+        postTraitChangeNotification (previousTraitCollection);
+}
+#endif
+
 - (BOOL) isAccessibilityElement
 {
     return NO;
@@ -1697,6 +1681,23 @@ bool KeyPress::isKeyCurrentlyDown (int keyCode)
 
 Point<float> juce_lastMousePos;
 
+struct ChangeRegistrationTrait
+{
+   #if JUCE_IOS_API_VERSION_CAN_BE_BUILT (17, 0)
+    API_AVAILABLE (ios (17))
+    static void newFn (UIView* view)
+    {
+        [view registerForTraitChanges: @[UITraitUserInterfaceStyle.self]
+                          withHandler: ^(JuceUIView*, UITraitCollection* previousTraitCollection)
+        {
+            postTraitChangeNotification (previousTraitCollection);
+        }];
+    }
+   #endif
+
+    static void oldFn (UIView*) {}
+};
+
 //==============================================================================
 UIViewComponentPeer::UIViewComponentPeer (Component& comp, int windowStyleFlags, UIView* viewToAttachTo)
     : ComponentPeer (comp, windowStyleFlags),
@@ -1723,6 +1724,8 @@ UIViewComponentPeer::UIViewComponentPeer (Component& comp, int windowStyleFlags,
     if ((windowStyleFlags & ComponentPeer::windowRequiresSynchronousCoreGraphicsRendering) == 0)
         [[view layer] setDrawsAsynchronously: YES];
 
+    ifelse_17_0<ChangeRegistrationTrait> (view);
+
     if (isSharedWindow)
     {
         window = [viewToAttachTo window];
@@ -2160,9 +2163,9 @@ void UIViewComponentPeer::dismissPendingTextInput()
 }
 
 //==============================================================================
-void UIViewComponentPeer::displayLinkCallback()
+void UIViewComponentPeer::displayLinkCallback (double timestampSec)
 {
-    vBlankListeners.call ([] (auto& l) { l.onVBlank(); });
+    callVBlankListeners (timestampSec);
 
     if (deferredRepaints.isEmpty())
         return;
@@ -2219,7 +2222,7 @@ void Desktop::setKioskComponent (Component* kioskModeComp, bool enableOrDisable,
 
 void Desktop::allowedOrientationsChanged()
 {
-   #if defined (__IPHONE_16_0) && __IPHONE_OS_VERSION_MAX_ALLOWED >= __IPHONE_16_0
+   #if JUCE_IOS_API_VERSION_CAN_BE_BUILT (16, 0)
     if (@available (iOS 16.0, *))
     {
         UIApplication* sharedApplication = [UIApplication sharedApplication];
